@@ -37,6 +37,7 @@ from IPython.core.magic import (
     magics_class,
     needs_local_scope,
     no_var_expand,
+    output_can_be_silenced,
     on_off,
 )
 from IPython.testing.skipdoctest import skip_doctest
@@ -511,7 +512,7 @@ class ExecutionMagics(Magics):
         """Run the named file inside IPython as a program.
 
         Usage::
-        
+
           %run [-n -i -e -G]
                [( -t [-N<N>] | -d [-b<N>] | -p [profile options] )]
                ( -m mod | filename ) [args]
@@ -552,7 +553,7 @@ class ExecutionMagics(Magics):
         *two* back slashes (e.g. ``\\\\*``) to suppress expansions.
         To completely disable these expansions, you can use -G flag.
 
-        On Windows systems, the use of single quotes `'` when specifying 
+        On Windows systems, the use of single quotes `'` when specifying
         a file is not supported. Use double quotes `"`.
 
         Options:
@@ -1194,6 +1195,7 @@ class ExecutionMagics(Magics):
     @no_var_expand
     @needs_local_scope
     @line_cell_magic
+    @output_can_be_silenced
     def time(self,line='', cell=None, local_ns=None):
         """Time execution of a Python statement or expression.
 
